@@ -1,5 +1,4 @@
 package DBIx::Class::Schema::Loader::Writing;
-use strict;
 
 # Empty. POD only.
 
@@ -17,8 +16,13 @@ DBIx::Class::Schema::Loader::Writing - Loader subclass writing guide
 
   use strict;
   use warnings;
-  use base 'DBIx::Class::Schema::Loader::Base';
   use Class::C3;
+  use base 'DBIx::Class::Schema::Loader::Generic';
+
+  sub _db_classes {
+      return qw/DBIx::Class::PK::Auto::Foo/;
+          # You may want to return more, or less, than this.
+  }
 
   sub _tables {
       my $self = shift;
@@ -47,6 +51,4 @@ DBIx::Class::Schema::Loader::Writing - Loader subclass writing guide
       ...
   }
 
-  1;
-
 =cut
